from typing import Any

MB_URL: str
MB_VERSION_ID: str
admin_id_: int
token_: str
timeout_: int

def set_admin_id(admin_id: int) -> None: ...
def set_token(token: str) -> None: ...
def set_timeout(timeout: int) -> None: ...
def make_request(path: str, data: dict[str, Any] | None = None, method: str = 'post', params: dict[str, Any] | None = None) -> Any: ...
def http_get(path: str, params: dict[str, Any] | None = None) -> Any: ...
def http_post(path: str, data: dict[str, Any] | None = None) -> Any: ...
def http_patch(path: str, data: dict[str, Any] | None = None) -> Any: ...
def http_delete(path: str) -> Any: ...
